@@ -1,6 +1,6 @@
 ".onAttach" <- function(lib, pkg) {
   mylib <- dirname(system.file(package = pkg))
-  title <- packageDescription(pkg, lib.loc = mylib)$Title
-  ver <- packageDescription(pkg, lib.loc = mylib)$Version
+  title <- packageDescription(pkg)$Title
+  ver <- packageDescription(pkg)$Version
   packageStartupMessage(paste(pkg, ": ", title, "\nVersion: ", ver, "\n", sep=""))
 }
